eprllib.Agents — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.Agents

## Agents

This module contains classes for representing and manipulating agents in the environment. The agents are responsible for taking actions in the environment following a specified policy.

Modules

`AgentSpec` | Agent Spec
`ConventionalAgent` | Conventional Agent
`OnOffAirConditionerControl` | On-Off Air Conditioner Control Agent
`WindowOpeningControl` | Window Opening Control Agent
`WindowShadeControl` | Window Shade Control Agent